OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Pyyntö epäonnistui, yhteys ei ole käytettävissä!",
    "Request unauthorized. Are you logged in?" : "Pyyntö ei ole valtutettu. Oletko sisäänkirjautuneena?",
    "Request forbidden. Are you an admin?" : "Pyyntö evätty. Oletko ylläpitäjä?",
    "Token expired or app not enabled! Reload the page!" : "Valtuutus vanheni tai sovellus ei ole käytössä! Lataa sivu uudelleen!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Sisäinen palvelinvirhe! Tarkista lisätiedot lokitiedostosta data/nextcloud.log!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Pyyntö epäonnistui, Nextcloud on parhaillaan ylläpitotilassa!",
    "News" : "Uutiset",
    "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
    "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
    "Disable this if you run a custom updater such as the Python updater included in the app." : "Poista tämä käytöstä jos käytät muuta päivittäjää, kuten sovelluksen Python-päivittäjää.",
    "Purge interval" : "Hävitysväli",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored." : "Minimiaika sekunteina jonka jälkeen poistetut syötteet ja kansiot poistetaan tietokannasta; alle 60 sekuntin arvot ohitetaan.",
    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
    "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
    "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
    "For more information check the wiki." : "Lue lisätietoja wikistä.",
    "Update interval" : "Päivitysväli",
    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
    "Saved" : "Tallennettu",
    "Download" : "Lataa",
    "Close" : "Sulje",
    "Subscribe to" : "Tilaa",
    "No articles available" : "Artikkeleita ei ole saatavilla",
    "No unread articles available" : "Lukemattomia artikkeleita ei ole saatavilla",
    "Open website" : "Avaa verkkosivu",
    "Star article" : "Merkitse artikkeli tähdellä",
    "Unstar article" : "Poista artikkelin tähtimerkintä",
    "Keep article unread" : "Pidä artikkeli lukemattomana",
    "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
    "by" : "Kirjoittaja:",
    "from" : "Syöte:",
    "Play audio" : "Toista äänet",
    "Download audio" : "Lataa äänet",
    "Download video" : "Lataa video",
    "Keyboard shortcut" : "Näppäimistön pikanäppäin",
    "Description" : "Kuvaus",
    "right" : "oikea",
    "Jump to next article" : "Siirry seuraavaan artikkeliin",
    "left" : "vasen",
    "Jump to previous article" : "Siirry edelliseen artikkeliin",
    "Toggle star article" : "Aseta tähti/poista tähti",
    "Star article and jump to next one" : "Aseta tähti artikkelille ja siirry seuraavaan",
    "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
    "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
    "Toggle expand article in compact view" : "Laajenna artikkeli tiivissä näkymässä/supista artikkeli",
    "Refresh" : "Päivitä",
    "Load next feed" : "Lataa seuraava syöte",
    "Load previous feed" : "Lataa edellinen syöte",
    "Load next folder" : "Lataa seuraava kansio",
    "Load previous folder" : "Lataa edellinen kansio",
    "Scroll to active navigation entry" : "Vieritä syötelista aktiivisen syötteen kohdalle",
    "Focus search field" : "Kohdista hakukenttään",
    "Mark current article's feed/folder read" : "Merkitse nykyisen artikkelin syöte/kansio luetuksi",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
    "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a",
    "Subscribe" : "Tilaa",
    "Web address" : "Verkko-osoite",
    "Feed exists already!" : "Syöte on jo olemassa!",
    "Folder" : "Kansio",
    "No folder" : "Ei kansiota",
    "New folder" : "Uusi kansio",
    "Folder name" : "Kansion nimi",
    "Go back" : "Takaisin",
    "Folder exists already!" : "Kansio on jo olemassa!",
    "Credentials" : "Tilitiedot",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "New Folder" : "Uusi kansio",
    "Create" : "Luo",
    "Explore" : "Selaa",
    "Update failed more than 50 times" : "Päivitys epäonnistui yli 50 kertaa",
    "Deleted feed" : "Syöte poistettu",
    "Undo delete feed" : "Kumoa syötteen poistaminen",
    "Rename" : "Nimeä uudelleen",
    "Menu" : "Valikko",
    "Mark read" : "Merkitse luetuksi",
    "Unpin from top" : "Poista kiinnitys ylhäältä",
    "Pin to top" : "Kiinnitä ylös",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Default order" : "Oletusjärjestys",
    "Enable full text" : "Käytä koko tekstiä",
    "Disable full text" : "Poista käytöstä koko teksti",
    "Open feed URL" : "Avaa syötteen osoite",
    "Delete" : "Poista",
    "Dismiss" : "Hylkää",
    "Collapse" : "Kutista näkymää",
    "Deleted folder" : "Kansio poistettu",
    "Undo delete folder" : "Kumoa kansion poistaminen",
    "Starred" : "Suositut",
    "Unread articles" : "Lukemattomat artikkelit",
    "All articles" : "Kaikki artikkelit",
    "Settings" : "Asetukset",
    "Disable mark read through scrolling" : "Poista käytöstä luetuksi merkitseminen vierittäessä",
    "Compact view" : "Tiivis näkymä",
    "Show all articles" : "Näytä kaikki artikkelit",
    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ylimpänä)",
    "Subscriptions (OPML)" : "Tilaukset (OPML)",
    "Import" : "Tuo",
    "Export" : "Vie",
    "Error when importing: File does not contain valid OPML" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista OPML:ää",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Virhe tuotaessa: OPML ei sisällä syötteitä tai kansioita",
    "Unread/Starred Articles" : "Lukemattomat/tähdellä varustetut artikkelit",
    "Error when importing: file does not contain valid JSON" : "Virhe tuotaessa: tiedosto ei sisällä kelvollista JSONia",
    "Help" : "Ohje",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Documentation" : "Dokumentaatio",
    "Report a bug" : "Ilmoita viasta"
},
"nplurals=2; plural=(n != 1);");
